@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,10 +62,15 @@ import com.openexchange.i18n.I18nService;
 
 public class I18nImpl implements I18nService {
 
-    private static final Log LOG = LogFactory.getLog(I18nImpl.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(I18nImpl.class));
 
-    private ResourceBundle serverBundle = null;
+    private final ResourceBundle serverBundle;
 
+    /**
+     * Initializes a new {@link I18nImpl}.
+     * 
+     * @param bundle The resource bundle
+     */
     public I18nImpl(final ResourceBundle bundle) {
         serverBundle = bundle;
     }
