@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,13 +57,8 @@ import java.util.Properties;
  */
 public class POParser {
 
-    static final int CLASS_ID = 1;
-
     private final Properties headers = new Properties();
 
-    /**
-     * Default constructor.
-     */
     public POParser() {
         super();
     }
@@ -75,7 +70,7 @@ public class POParser {
         skipContexts(tokens);
         while (tokens.lookahead(POToken.MSGID)) {
             readTranslation(translations, tokens);
-            if (null != translations.translate("") && 0 == headers.size()) {
+            if (null != translations.translate("") && headers.isEmpty()) {
                 parseHeader(translations.translate(""));
                 setCharSet(tokens);
             }
@@ -131,9 +126,11 @@ public class POParser {
         }
 
         final String valueString = value.toString();
-        translations.setTranslation(key.toString(), valueString);
-        if (alternateKey != null) {
-            translations.setTranslation(alternateKey.toString(), valueString);
+        if (!"".equals(valueString)) {
+            translations.setTranslation(key.toString(), valueString);
+            if (alternateKey != null) {
+                translations.setTranslation(alternateKey.toString(), valueString);
+            }
         }
     }
 
